@@ -1,6 +1,6 @@
-// $Id: cellrenderer-indent.h,v 1.7 2005/11/02 12:33:38 cactus Exp $ -*- c++ -*-
+// $Id: cellrenderer-indent.h,v 1.9 2006/10/06 22:35:40 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2006 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -98,56 +98,55 @@ namespace Guikachu
         private:
             static void cell_cb (CellRenderer *cell, const Gtk::TreeModel::iterator &iter, Gtk::TreeView *treeview);
         };
+
+        /**** Template Implementation **********************************************/
+
+        template<class RealCell>
+        CellRendererIndent<RealCell>::CellRendererIndent ()
+        {
+            real_cell.property_mode ().signal_changed ().connect (
+                sigc::mem_fun (*this, &CellRendererIndent::real_cell_mode_changed_cb));
+        }
+
+        template<>
+        CellRendererIndent<Gtk::CellRendererText>::CellRendererIndent ();
+        
+        template<class RealCell>
+        CellRendererIndent<RealCell> * 
+        CellRendererIndent<RealCell>::setup_view (Gtk::TreeView                           &treeview,
+                                                  const Glib::ustring                     &title,
+                                                  const Gtk::TreeViewColumn::SlotCellData &slot)
+        {
+            Gtk::CellRenderer *empty_cell = new Gtk::CellRendererText;
+            Gtk::TreeView::Column *expander_col = new Gtk::TreeView::Column ("", *manage (empty_cell));
+            expander_col->set_visible (false);
+            treeview.append_column (*manage (expander_col));
+            treeview.set_expander_column (*expander_col);
+            
+            Gtk::TreeView::Column *column = new Gtk::TreeView::Column (title);
+            CellRendererIndent *indent_cell = new CellRendererIndent<RealCell>;
+            indent_cell->cell_slot = slot;
+            column->pack_start (*manage (indent_cell), true);    
+            column->set_cell_data_func (*indent_cell, sigc::bind (sigc::ptr_fun (&CellRendererIndent::cell_cb), &treeview));
+            treeview.append_column(*manage (column));
+            
+            treeview.signal_row_collapsed ().connect (
+                sigc::hide (sigc::hide (sigc::mem_fun (treeview, &Gtk::TreeView::expand_all))));
+            
+            return indent_cell;
+        }
+        
+        template<class RealCell>
+        void CellRendererIndent<RealCell>::cell_cb (CellRenderer                   *cell,
+                                                    const Gtk::TreeModel::iterator &iter,
+                                                    Gtk::TreeView                  *view)
+        {    
+            CellRendererIndent<RealCell> *cell_indent = dynamic_cast<CellRendererIndent<RealCell>*> (cell);
+            g_return_if_fail (cell_indent);
+            
+            cell_indent->set_depth (view->get_model ()->get_path (iter));
+            cell_indent->cell_slot (cell_indent->get_real_cell (), iter);
+        }
     }
 }
-
-/**** Template Implementation **********************************************/
-
-template<class RealCell>
-Guikachu::GUI::CellRendererIndent<RealCell>::CellRendererIndent ()
-{
-    real_cell.property_mode ().signal_changed ().connect (
-        sigc::mem_fun (*this, &CellRendererIndent::real_cell_mode_changed_cb));
-}
-
-template<>
-Guikachu::GUI::CellRendererIndent<Gtk::CellRendererText>::CellRendererIndent ();
-
-template<class RealCell>
-Guikachu::GUI::CellRendererIndent<RealCell> * 
-Guikachu::GUI::CellRendererIndent<RealCell>::setup_view (Gtk::TreeView                           &treeview,
-                                                         const Glib::ustring                     &title,
-                                                         const Gtk::TreeViewColumn::SlotCellData &slot)
-{
-    Gtk::CellRenderer *empty_cell = new Gtk::CellRendererText;
-    Gtk::TreeView::Column *expander_col = new Gtk::TreeView::Column ("", *manage (empty_cell));
-    expander_col->set_visible (false);
-    treeview.append_column (*manage (expander_col));
-    treeview.set_expander_column (*expander_col);
-
-    Gtk::TreeView::Column *column = new Gtk::TreeView::Column (title);
-    CellRendererIndent *indent_cell = new CellRendererIndent<RealCell>;
-    indent_cell->cell_slot = slot;
-    column->pack_start (*manage (indent_cell), true);    
-    column->set_cell_data_func (*indent_cell, sigc::bind (sigc::ptr_fun (&CellRendererIndent::cell_cb), &treeview));
-    treeview.append_column(*manage (column));
-
-    treeview.signal_row_collapsed ().connect (
-        sigc::hide (sigc::hide (sigc::mem_fun (treeview, &Gtk::TreeView::expand_all))));
-    
-    return indent_cell;
-}
-
-template<class RealCell>
-void Guikachu::GUI::CellRendererIndent<RealCell>::cell_cb (CellRenderer                   *cell,
-                                                           const Gtk::TreeModel::iterator &iter,
-                                                           Gtk::TreeView                  *view)
-{    
-    CellRendererIndent<RealCell> *cell_indent = dynamic_cast<CellRendererIndent<RealCell>*> (cell);
-    g_return_if_fail (cell_indent);
-
-    cell_indent->set_depth (view->get_model ()->get_path (iter));
-    cell_indent->cell_slot (cell_indent->get_real_cell (), iter);
-}
-
 #endif /* !GUIKACHU_CELLRENDERER_INDENT */
