@@ -1,6 +1,6 @@
-//$Id: screen-canvas.cc,v 1.2 2005/11/27 14:57:58 cactus Exp $ -*- c++ -*-
+//$Id: screen-canvas.cc,v 1.4 2006/10/06 22:35:42 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2006 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -30,7 +30,6 @@ ScreenCanvas::ScreenCanvas (Guikachu::Target *target_):
 {
     set_center_scroll_region (true);
         
-    Preferences::FormEditor::colors_changed.connect (sigc::mem_fun (*this, &ScreenCanvas::update));
     target->changed.connect (sigc::mem_fun (*this, &ScreenCanvas::update));    
     update ();
 }
@@ -55,6 +54,7 @@ ScreenCanvasItem::ScreenCanvasItem (FooCanvasmm::Group &parent_group,
     target (target_),
     item (0)
 {
+    Preferences::FormEditor::colors_changed.connect (sigc::mem_fun (*this, &ScreenCanvasItem::update));
     target->changed.connect (sigc::mem_fun (*this, &ScreenCanvasItem::update));    
     update ();
 }
