@@ -1,6 +1,6 @@
-//$Id: guikachu2rcp.cc,v 1.16 2005/11/29 21:16:46 cactus Exp $ -*- c++ -*-
+//$Id: guikachu2rcp.cc,v 1.18 2006/10/06 22:35:41 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2006 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -16,14 +16,14 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
-#include "config.h"
-
 #include <glib.h>
 #include <glib/gi18n.h>
 
 #include <glibmm/init.h>
 #include <gdkmm/wrap_init.h>
 
+#include "ui.h"
+
 #include "io/xml-loader.h"
 #include "io/rcp-saver.h"
 
@@ -92,13 +92,8 @@ void usage (const std::string &self_name)
 
 int main (int argc, char **argv)
 {
-#ifdef ENABLE_NLS
-    bindtextdomain (PACKAGE, GNOME_LOCALEDIR);
-    bind_textdomain_codeset (PACKAGE, "UTF-8");
-    textdomain (PACKAGE);
-#endif
-
     // Init subsystems
+    UI::init_i18n ();    
     Glib::init ();
     IO::init ();
     Gdk::wrap_init ();
