@@ -1,6 +1,6 @@
-//$Id: main.cc,v 1.30 2006/05/11 21:26:41 cactus Exp $ -*- c++ -*-
+//$Id: main.cc,v 1.32 2006/10/06 22:35:41 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2006 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -16,18 +16,15 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
-#include <glib/gi18n.h>
-
 #include "session.h"
+#include "ui.h"
 
+using namespace Guikachu;
+    
 int main (int argc, char **argv)
 {
-#ifdef ENABLE_NLS
-    bindtextdomain (PACKAGE, GNOME_LOCALEDIR);
-    bind_textdomain_codeset (PACKAGE, "UTF-8");
-    textdomain (PACKAGE);
-#endif
+    UI::init_i18n ();
     
-    Guikachu::Main app (argc, argv);
+    Main app (argc, argv);
     app.run ();
 }
