@@ -1,6 +1,6 @@
-//$Id: mainwin-menu.cc,v 1.5 2005/11/27 14:57:58 cactus Exp $ -*- c++ -*-
+//$Id: mainwin-menu.cc,v 1.7 2006/10/06 22:35:41 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2006 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -38,7 +38,7 @@ namespace {
     Glib::ustring escape_underscores (const Glib::ustring &text);
 } // Anonymous namespace
 
-#define GN_(s) dgettext ("libgnomeui-2.0", (s))
+#define GN_(s) dgettext ("gtk20", (s))
 
 void GUI::MainWin::create_menus ()
 {
@@ -51,13 +51,13 @@ void GUI::MainWin::create_menus ()
     main_group->add (action,
                      sigc::mem_fun (*this, &MainWin::new_cb));
     main_group->add (Gtk::Action::create ("open", Gtk::Stock::OPEN, "",
-                                          GN_("Open a file")),
+                                          _("Open a file")),
                      sigc::mem_fun (*this, &MainWin::load_cb));
     main_group->add (Gtk::Action::create ("save", Gtk::Stock::SAVE, "",
-                                          GN_("Save the current file")),
+                                          _("Save the current file")),
                      sigc::mem_fun (*this, &MainWin::save_cb));
     main_group->add (Gtk::Action::create ("save_as", Gtk::Stock::SAVE_AS, "",
-                                          GN_("Save the current file with a different name")),
+                                          _("Save the current file with a different name")),
                      Gtk::AccelKey ("<control><shift>S"),
                      sigc::mem_fun (*this, &MainWin::save_as_cb));
     main_group->add (Gtk::Action::create ("export_rcp", Gtk::Stock::CONVERT,
@@ -73,7 +73,7 @@ void GUI::MainWin::create_menus ()
                      Gtk::AccelKey ("<control>a"),
                      sigc::mem_fun (*this, &MainWin::add_cb));
     main_group->add (Gtk::Action::create ("exit", Gtk::Stock::QUIT, "",
-                                          GN_("Quit the application")),
+                                          _("Quit the application")),
                      sigc::mem_fun (*this, &MainWin::exit_cb));
     
     // Edit menu
@@ -89,13 +89,13 @@ void GUI::MainWin::create_menus ()
     main_group->add (action, Gtk::AccelKey ("<control><shift>z"),
                      sigc::mem_fun (*this, &MainWin::redo_cb));
     main_group->add (Gtk::Action::create ("cut", Gtk::Stock::CUT, "",
-                                          GN_("Cut the selection")),
+                                          _("Cut the selection")),
                      sigc::mem_fun (*this, &MainWin::cut_cb));
     main_group->add (Gtk::Action::create ("copy", Gtk::Stock::COPY, "",
-                                          GN_("Copy the selection")),
+                                          _("Copy the selection")),
                      sigc::mem_fun (*this, &MainWin::copy_cb));
     main_group->add (Gtk::Action::create ("paste", Gtk::Stock::PASTE, "",
-                                          GN_("Paste the clipboard")),
+                                          _("Paste the clipboard")),
                      sigc::mem_fun (*this, &MainWin::paste_cb));
     main_group->add (Gtk::Action::create ("duplicate", _("_Duplicate"),
                                           _("Duplicate the selected resource")),
@@ -106,11 +106,11 @@ void GUI::MainWin::create_menus ()
                      Gtk::AccelKey ("Delete"),
                      sigc::mem_fun (*this, &MainWin::remove_cb));
     main_group->add (Gtk::Action::create ("preferences", Gtk::Stock::PREFERENCES, "",
-                                          GN_("Configure the application")),
+                                          _("Configure the application")),
                      sigc::mem_fun (*this, &MainWin::preferences_cb));
 
     // View menu
-    main_group->add (Gtk::Action::create ("menu_view", GN_("_View")));
+    main_group->add (Gtk::Action::create ("menu_view", _("_View")));
     main_group->add (Gtk::ToggleAction::create ("toggle_toolbar", _("_Toolbar"),
                                                 _("Toggles the main window's toolbar"),
                                                 true),
@@ -127,7 +127,7 @@ void GUI::MainWin::create_menus ()
     // Help menu
     main_group->add (Gtk::Action::create ("menu_help", GN_("_Help")));
     main_group->add (Gtk::Action::create ("about", Gtk::Stock::ABOUT, "",
-                                          GN_("About this application")),
+                                          _("About this application")),
                      sigc::bind (sigc::ptr_fun (&UI::show_about), this));
     
     static const char *ui_description =
