@@ -1,6 +1,6 @@
-//$Id: ui-gui.cc,v 1.21 2006/05/11 21:26:41 cactus Exp $ -*- c++ -*-
+//$Id: ui-gui.cc,v 1.23 2006/10/06 22:35:41 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2006 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -81,17 +81,17 @@ void UI::show_about (Gtk::Window *parent)
 	translators = "";
 
     static const char *license =
-        "This program is free software; you can redistribute it and/or modify it\n"
-        "under the terms of the GNU General Public License version 2 as published\n"
+        "This program is free software; you can redistribute it and/or modify it "
+        "under the terms of the GNU General Public License version 2 as published "
         "by the Free Software Foundation.\n"
         "\n"
-        "This program is distributed in the hope that it will be useful but WITHOUT\n"
-        "ANY WARRANTY; without even the implied warranty of MERCHANTABILITY\n"
-        "or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public \n"
+        "This program is distributed in the hope that it will be useful but WITHOUT "
+        "ANY WARRANTY; without even the implied warranty of MERCHANTABILITY "
+        "or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public "
         "License for more details.\n"
         "\n"
-        "You should have received a copy of the GNU General Public License along\n"
-        "with this program; if not, write to the Free Software Foundation, Inc.,\n"
+        "You should have received a copy of the GNU General Public License along "
+        "with this program; if not, write to the Free Software Foundation, Inc., "
         "59 Temple Place, Suite 330, Boston, MA 02111-1307 USA";
     
     Gtk::AboutDialog *about = new Gtk::AboutDialog;
@@ -101,7 +101,7 @@ void UI::show_about (Gtk::Window *parent)
     
     about->set_name ("Guikachu");
     about->set_version (VERSION);
-    about->set_copyright ("Copyright \xC2\xA9 2001-2005 Gerg\xC5\x91 \xC3\x89rdi");
+    about->set_copyright ("Copyright \xC2\xA9 2001-2006 Gerg\xC5\x91 \xC3\x89rdi");
     about->set_comments (_("PalmOS resource file editor"));
     about->set_website ("http://cactus.rulez.org/projects/guikachu/");
     about->set_website_label (_("Visit the Guikachu website"));
@@ -113,6 +113,7 @@ void UI::show_about (Gtk::Window *parent)
 
     about->set_logo (logo);
     about->set_license (license);
+    about->set_wrap_license (true);
 
     if (parent)
         about->set_transient_for (*parent);
