@@ -1,6 +1,6 @@
-//$Id: ui.cc,v 1.5 2005/07/29 09:54:14 cactus Exp $ -*- c++ -*-
+//$Id: ui.cc,v 1.7 2006/10/06 22:35:41 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2005 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2006 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -16,12 +16,34 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
+#include "config.h"
+
 #include "ui.h"
 
 #include <glib.h>
+#include <glib/gi18n.h>
+#include <glib/gwin32.h>
 
 using namespace Guikachu;
 
+void UI::init_i18n ()
+{
+#ifdef ENABLE_NLS
+#ifdef _WIN32
+    char *localedir = g_win32_get_package_installation_subdirectory (0, 0, GUIKACHU_DATADIRNAME "\\locale");
+    if (localedir)
+        bindtextdomain (PACKAGE, localedir);
+    else
+        bindtextdomain (PACKAGE, GUIKACHU_LOCALEDIR);
+    g_free (localedir);    
+#else
+    bindtextdomain (PACKAGE, GUIKACHU_LOCALEDIR);
+#endif
+    bind_textdomain_codeset (PACKAGE, "UTF-8");
+    textdomain (PACKAGE);
+#endif    
+}
+
 Glib::ustring UI::visible_filename (const Glib::ustring &uri)
 {
     // FIXME: Ensure UTF-8-safetiness
